@@ -47,6 +47,7 @@ public:
         SdrBrightnessRole,
         MaxBrightnessRole,
         SdrGamutWideness,
+        ColorProfileSource,
         InteractiveMoveRole, // This output is currently repositioned interactively
     };
 
@@ -86,19 +87,21 @@ private:
         Output(const Output &output)
             : ptr(output.ptr)
             , pos(output.pos)
+            , posReset(output.pos)
         {
         }
         Output(Output &&) noexcept = default;
         Output(KScreen::OutputPtr _ptr, const QPoint &_pos)
             : ptr(_ptr)
             , pos(_pos)
+            , posReset(_pos)
         {
         }
         Output &operator=(const Output &output)
         {
             ptr = output.ptr;
             pos = output.pos;
-            posReset = std::nullopt;
+            posReset = output.posReset;
             return *this;
         }
         Output &operator=(Output &&) noexcept = default;
